@@ -570,18 +570,18 @@ sub gnuOptimizeOpt() {
 
     if ($brokenCompiler) {
         print("You appear to have a broken compiler which would produce \n");
-        print("incorrect code if requested to to do inline optimization.\n");
+        print("incorrect code if requested to do inline optimization.\n");
         print("Therefore, I am configuring the build to not do inline \n");
         print("optimization.  This will make some Netpbm programs \n");
         print("noticeably slower.  If I am wrong about your compiler, just\n");
-        print("edit Makefile.config and change -O2 to -O3 near the bottom.\n");
+        print("edit Makefile.config and change -O0 to -O3 near the bottom.\n");
         print("\n");
         print("The problem is known to exist in the GNU Compiler \n");
         print("release 2.96.  If you upgrade, you will not have this \n");
         print("problem.\n");
         print("---------------------------------------------\n");
         print("\n");
-        $oOpt = "-O2";
+        $oOpt = "-O0";
     } else {
         $oOpt = "-O3";
     }
@@ -864,6 +864,9 @@ print("\n");
 	    }
             if ($platform eq "AIX") {
                 $netpbmlibsuffix = "a";
+                print("I don't know how to make a shared library on AIX.  " .
+                      "If you do, please clue in the Netpbm maintainer.\n");
+                exit(1)
             } elsif ($platform eq "HP-UX") {
                 $netpbmlibsuffix = "sl";
             } else {
@@ -1051,7 +1054,9 @@ push(@Makefile_config, "####Lines above were copied from Makefile.config.in " .
      "by 'configure'.\n");
 push(@Makefile_config, "####Lines below were added by 'configure' based on " .
      "the $platform platform.\n");
-
+if (defined($subplatform)) {
+    push(@Makefile_config, "####subplatform '$subplatform'\n");
+}
 
 push(@Makefile_config, "DEFAULT_TARGET = $default_target\n");
 
