@@ -262,7 +262,7 @@ language_declaration(const char input_filespec[], int const verbose) {
     else {
         const char eps_header[] = "%!PS-Adobe EPSF-3.0";
 
-        if (strncmp(line, eps_header, sizeof(eps_header)))
+        if (strncmp(line, eps_header, sizeof(eps_header)) == 0)
             language = ENCAPSULATED_POSTSCRIPT;
         else
             language = COMMON_POSTSCRIPT;
